==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/GetVirtualNetworkRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.GetVirtualNetworkRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serverName The name of the server.
 * @property virtualNetworkRuleName The name of the virtual network rule.
 */
public data class GetVirtualNetworkRulePlainArgs(
    public val resourceGroupName: String,
    public val serverName: String,
    public val virtualNetworkRuleName: String,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.GetVirtualNetworkRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.GetVirtualNetworkRulePlainArgs =
        com.pulumi.azurenative.sql.inputs.GetVirtualNetworkRulePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serverName(serverName.let({ args0 -> args0 }))
            .virtualNetworkRuleName(virtualNetworkRuleName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualNetworkRulePlainArgs].
 */
@PulumiTagMarker
public class GetVirtualNetworkRulePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var serverName: String? = null

    private var virtualNetworkRuleName: String? = null

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("ixqvijullwhctfvd")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("tyrbsuvgqrqubvfk")
    public suspend fun serverName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serverName = mapped
    }

    /**
     * @param value The name of the virtual network rule.
     */
    @JvmName("vpcfrtpnkbojbegh")
    public suspend fun virtualNetworkRuleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.virtualNetworkRuleName = mapped
    }

    internal fun build(): GetVirtualNetworkRulePlainArgs = GetVirtualNetworkRulePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serverName = serverName ?: throw PulumiNullFieldException("serverName"),
        virtualNetworkRuleName = virtualNetworkRuleName ?: throw
            PulumiNullFieldException("virtualNetworkRuleName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/GetVirtualNetworkRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.GetVirtualNetworkRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serverName The name of the server.
 * @property virtualNetworkRuleName The name of the virtual network rule.
 */
public data class GetVirtualNetworkRulePlainArgs(
    public val resourceGroupName: String,
    public val serverName: String,
    public val virtualNetworkRuleName: String,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.GetVirtualNetworkRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.GetVirtualNetworkRulePlainArgs =
        com.pulumi.azurenative.sql.inputs.GetVirtualNetworkRulePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serverName(serverName.let({ args0 -> args0 }))
            .virtualNetworkRuleName(virtualNetworkRuleName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualNetworkRulePlainArgs].
 */
@PulumiTagMarker
public class GetVirtualNetworkRulePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var serverName: String? = null

    private var virtualNetworkRuleName: String? = null

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("twymfpgkynoriwfx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("rbdhxetxymcehawc")
    public suspend fun serverName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serverName = mapped
    }

    /**
     * @param value The name of the virtual network rule.
     */
    @JvmName("xllndjmjfgkvovmh")
    public suspend fun virtualNetworkRuleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.virtualNetworkRuleName = mapped
    }

    internal fun build(): GetVirtualNetworkRulePlainArgs = GetVirtualNetworkRulePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serverName = serverName ?: throw PulumiNullFieldException("serverName"),
        virtualNetworkRuleName = virtualNetworkRuleName ?: throw
            PulumiNullFieldException("virtualNetworkRuleName"),
    )
}
